---
title: <span class="badge object-type-enum"></span> PromQueryFormat
---
# <span class="badge object-type-enum"></span> PromQueryFormat

## Definition

```python
class PromQueryFormat(enum.StrEnum):
    TIME_SERIES = "time_series"
    TABLE = "table"
    HEATMAP = "heatmap"
```
